@@ -1,5 +1,8 @@
 ################################################################################
 ################################################################################
+##
+##
+#'@noRd
 
 GridP<- function(Yt, Event, nT = NULL){
     if (is.null(Event))stop("Bad input Event")
@@ -30,7 +33,6 @@ GridP<- function(Yt, Event, nT = NULL){
   Break=a
   return(Break)
 }
-GridP <- cmpfun(GridP)
 ################################################################################
 ################################################################################
 
